"use client";
import { Bar, BarChart, CartesianGrid, LabelList, XAxis } from "recharts";

import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { type ChartConfig, ChartContainer, ChartTooltip, ChartTooltipContent } from "@/components/ui/chart";

export const description = "Ein Balkendiagramm mit Beschriftung";

interface PrintVolumes {
	today: number;
	thisWeek: number;
	thisMonth: number;
}

const chartConfig = {
	volume: {
		label: "Volumen",
	},
} satisfies ChartConfig;

interface PrinterVolumeChartProps {
	printerVolume: PrintVolumes;
}

export function PrinterVolumeChart({ printerVolume }: PrinterVolumeChartProps) {
	const chartData = [
		{ period: "Heute", volume: printerVolume.today, color: "hsl(var(--chart-1))" },
		{ period: "Diese Woche", volume: printerVolume.thisWeek, color: "hsl(var(--chart-2))" },
		{ period: "Diesen Monat", volume: printerVolume.thisMonth, color: "hsl(var(--chart-3))" },
	];

	return (
		<Card>
			<CardHeader>
				<CardTitle>Druckvolumen</CardTitle>
				<CardDescription>Vergleich: Heute, Diese Woche, Diesen Monat</CardDescription>
			</CardHeader>
			<CardContent>
				<ChartContainer className="h-64 w-full" config={chartConfig}>
					<BarChart
						accessibilityLayer
						data={chartData}
						margin={{
							top: 20,
						}}
					>
						<CartesianGrid vertical={false} />
						<XAxis
							dataKey="period"
							tickLine={false}
							tickMargin={10}
							axisLine={false}
							tickFormatter={(value) => value}
						/>
						<ChartTooltip cursor={false} content={<ChartTooltipContent hideLabel />} />
						<Bar dataKey="volume" fill="var(--color-volume)" radius={8}>
							<LabelList position="top" offset={12} className="fill-foreground" fontSize={12} />
						</Bar>
					</BarChart>
				</ChartContainer>
			</CardContent>
			<CardFooter className="flex-col items-start gap-2 text-sm">
				<div className="leading-none text-muted-foreground">
					Zeigt das Druckvolumen für heute, diese Woche und diesen Monat
				</div>
			</CardFooter>
		</Card>
	);
}
